v1alpha1

package
v0.0.0-...-477b72e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 12, 2023 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package v1alpha1 is the v1alpha1 version of the API.

Index

Constants

const (
	Version = "v1alpha1"
)

Variables

var (
	// SchemeBuilder initializes a scheme builder
	SchemeBuilder = runtime.NewSchemeBuilder(addKnowTypes)
	// AddToScheme is a global function that registers this API group & version to a scheme
	AddToScheme = SchemeBuilder.AddToScheme
)
var (
	// SchemeGroupPROJECT_VERSION is group version used to register these objects
	SchemeGroupVersion = schema.GroupVersion{Group: miniooperator.GroupName, Version: Version}
)

Functions

func Kind

func Kind(kind string) schema.GroupKind

Kind takes an unqualified kind and returns back a Group qualified GroupKind

func MinioDefaulter

func MinioDefaulter(minio *Minio)

func Resource

func Resource(resource string) schema.GroupResource

Resource takes an unqualified resource and returns a Group-qualified GroupResource.

Types

type Credential

type Credential struct {
	AccessKey string `json:"access_key"`
	SecretKey string `json:"secret_key"`
}

Credential represent credential

type Minio

type Minio struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`

	Spec   MinioSpec   `json:"spec"`
	Status MinioStatus `json:"status"`
}

Minio defines Minio deployment

func (*Minio) DeepCopy

func (in *Minio) DeepCopy() *Minio

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Minio.

func (*Minio) DeepCopyInto

func (in *Minio) DeepCopyInto(out *Minio)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*Minio) DeepCopyObject

func (in *Minio) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type MinioList

type MinioList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`

	Items []Minio `json:"items"`
}

MinioList carries a list of Minio objects

func (*MinioList) DeepCopy

func (in *MinioList) DeepCopy() *MinioList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MinioList.

func (*MinioList) DeepCopyInto

func (in *MinioList) DeepCopyInto(out *MinioList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*MinioList) DeepCopyObject

func (in *MinioList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type MinioSpec

type MinioSpec struct {
	Replicas   int32       `json:"replicas"`
	Image      string      `json:"image"`
	HostPath   string      `json:"hostpath"`
	Buckets    []string    `json:"buckets"`
	Credential Credential  `json:"credential"`
	Port       ServicePort `json:"port"`
}

MinioSpec describes the specification of Minio applications using kubernetes as a cluster manager

func (*MinioSpec) DeepCopy

func (in *MinioSpec) DeepCopy() *MinioSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MinioSpec.

func (*MinioSpec) DeepCopyInto

func (in *MinioSpec) DeepCopyInto(out *MinioSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type MinioStatus

type MinioStatus struct {
	Inited string `json:"inited"`
}

MinioStatus describes the current status of Minio applications

func (*MinioStatus) DeepCopy

func (in *MinioStatus) DeepCopy() *MinioStatus

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MinioStatus.

func (*MinioStatus) DeepCopyInto

func (in *MinioStatus) DeepCopyInto(out *MinioStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ServicePort

type ServicePort struct {
	HttpPort int32 `json:"http_port"`
	ApiPort  int32 `json:"apiport"`
	NodePort int32 `json:"nodeport"`
}

Jump to