Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MinioExpansion ¶
type MinioExpansion interface{}
type MinioInterface ¶
type MinioInterface interface {
Create(ctx context.Context, minio *v1alpha1.Minio, opts v1.CreateOptions) (*v1alpha1.Minio, error)
Update(ctx context.Context, minio *v1alpha1.Minio, opts v1.UpdateOptions) (*v1alpha1.Minio, error)
UpdateStatus(ctx context.Context, minio *v1alpha1.Minio, opts v1.UpdateOptions) (*v1alpha1.Minio, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.Minio, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.MinioList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.Minio, err error)
MinioExpansion
}
MinioInterface has methods to work with Minio resources.
type MiniooperatorV1alpha1Client ¶
type MiniooperatorV1alpha1Client struct {
// contains filtered or unexported fields
}
MiniooperatorV1alpha1Client is used to interact with features provided by the miniooperator.3xpl0it3r.cn group.
func New ¶
func New(c rest.Interface) *MiniooperatorV1alpha1Client
New creates a new MiniooperatorV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*MiniooperatorV1alpha1Client, error)
NewForConfig creates a new MiniooperatorV1alpha1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new MiniooperatorV1alpha1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *MiniooperatorV1alpha1Client
NewForConfigOrDie creates a new MiniooperatorV1alpha1Client for the given config and panics if there is an error in the config.
func (*MiniooperatorV1alpha1Client) Minios ¶
func (c *MiniooperatorV1alpha1Client) Minios(namespace string) MinioInterface
func (*MiniooperatorV1alpha1Client) RESTClient ¶
func (c *MiniooperatorV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type MiniooperatorV1alpha1Interface ¶
type MiniooperatorV1alpha1Interface interface {
RESTClient() rest.Interface
MiniosGetter
}
type MiniosGetter ¶
type MiniosGetter interface {
Minios(namespace string) MinioInterface
}
MiniosGetter has a method to return a MinioInterface. A group's client should implement this interface.