Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MinioLister ¶
type MinioLister interface {
// List lists all Minios in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Minio, err error)
// Minios returns an object that can list and get Minios.
Minios(namespace string) MinioNamespaceLister
MinioListerExpansion
}
MinioLister helps list Minios. All objects returned here must be treated as read-only.
func NewMinioLister ¶
func NewMinioLister(indexer cache.Indexer) MinioLister
NewMinioLister returns a new MinioLister.
type MinioListerExpansion ¶
type MinioListerExpansion interface{}
MinioListerExpansion allows custom methods to be added to MinioLister.
type MinioNamespaceLister ¶
type MinioNamespaceLister interface {
// List lists all Minios in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Minio, err error)
// Get retrieves the Minio from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.Minio, error)
MinioNamespaceListerExpansion
}
MinioNamespaceLister helps list and get Minios. All objects returned here must be treated as read-only.
type MinioNamespaceListerExpansion ¶
type MinioNamespaceListerExpansion interface{}
MinioNamespaceListerExpansion allows custom methods to be added to MinioNamespaceLister.
Click to show internal directories.
Click to hide internal directories.